summaryrefslogtreecommitdiffstats
path: root/google_apis
diff options
context:
space:
mode:
Diffstat (limited to 'google_apis')
-rw-r--r--google_apis/gaia/account_tracker.cc20
-rw-r--r--google_apis/gaia/gaia_auth_fetcher.cc6
-rw-r--r--google_apis/gaia/gaia_oauth_client.cc6
-rw-r--r--google_apis/gaia/identity_provider.cc6
-rw-r--r--google_apis/gaia/oauth2_access_token_fetcher_impl.cc6
-rw-r--r--google_apis/gaia/oauth2_api_call_flow.cc6
-rw-r--r--google_apis/gaia/oauth2_token_service.cc10
-rw-r--r--google_apis/gcm/base/socket_stream.cc6
8 files changed, 33 insertions, 33 deletions
diff --git a/google_apis/gaia/account_tracker.cc b/google_apis/gaia/account_tracker.cc
index b134fc0..1c29ee6 100644
--- a/google_apis/gaia/account_tracker.cc
+++ b/google_apis/gaia/account_tracker.cc
@@ -6,7 +6,7 @@
#include "base/debug/trace_event.h"
#include "base/logging.h"
-#include "base/profiler/scoped_profile.h"
+#include "base/profiler/scoped_tracker.h"
#include "base/stl_util.h"
#include "net/url_request/url_request_context_getter.h"
@@ -85,8 +85,8 @@ AccountIds AccountTracker::FindAccountIdsByGaiaId(const std::string& gaia_id) {
}
void AccountTracker::OnRefreshTokenAvailable(const std::string& account_id) {
- // TODO(vadimt): Remove ScopedProfile below once crbug.com/422460 is fixed.
- tracked_objects::ScopedProfile tracking_profile(
+ // TODO(vadimt): Remove ScopedTracker below once crbug.com/422460 is fixed.
+ tracked_objects::ScopedTracker tracking_profile(
FROM_HERE_WITH_EXPLICIT_FUNCTION(
"422460 AccountTracker::OnRefreshTokenAvailable"));
@@ -164,8 +164,8 @@ void AccountTracker::NotifyAccountRemoved(const AccountState& account) {
}
void AccountTracker::NotifySignInChanged(const AccountState& account) {
- // TODO(vadimt): Remove ScopedProfile below once crbug.com/422460 is fixed.
- tracked_objects::ScopedProfile tracking_profile(
+ // TODO(vadimt): Remove ScopedTracker below once crbug.com/422460 is fixed.
+ tracked_objects::ScopedTracker tracking_profile(
FROM_HERE_WITH_EXPLICIT_FUNCTION(
"422460 AccountTracker::NotifySignInChanged"));
@@ -177,7 +177,7 @@ void AccountTracker::NotifySignInChanged(const AccountState& account) {
void AccountTracker::UpdateSignInState(const std::string account_key,
bool is_signed_in) {
- tracked_objects::ScopedProfile tracking_profile(
+ tracked_objects::ScopedTracker tracking_profile(
FROM_HERE_WITH_EXPLICIT_FUNCTION(
"422460 AccountTracker::UpdateSignInState"));
@@ -195,8 +195,8 @@ void AccountTracker::UpdateSignInState(const std::string account_key,
}
void AccountTracker::StartTrackingAccount(const std::string account_key) {
- // TODO(vadimt): Remove ScopedProfile below once crbug.com/422460 is fixed.
- tracked_objects::ScopedProfile tracking_profile(
+ // TODO(vadimt): Remove ScopedTracker below once crbug.com/422460 is fixed.
+ tracked_objects::ScopedTracker tracking_profile(
FROM_HERE_WITH_EXPLICIT_FUNCTION(
"422460 AccountTracker::StartTrackingAccount"));
@@ -231,8 +231,8 @@ void AccountTracker::StopTrackingAllAccounts() {
}
void AccountTracker::StartFetchingUserInfo(const std::string account_key) {
- // TODO(vadimt): Remove ScopedProfile below once crbug.com/422460 is fixed.
- tracked_objects::ScopedProfile tracking_profile(
+ // TODO(vadimt): Remove ScopedTracker below once crbug.com/422460 is fixed.
+ tracked_objects::ScopedTracker tracking_profile(
FROM_HERE_WITH_EXPLICIT_FUNCTION(
"422460 AccountTracker::StartFetchingUserInfo"));
diff --git a/google_apis/gaia/gaia_auth_fetcher.cc b/google_apis/gaia/gaia_auth_fetcher.cc
index 83dae59e..0d384a0 100644
--- a/google_apis/gaia/gaia_auth_fetcher.cc
+++ b/google_apis/gaia/gaia_auth_fetcher.cc
@@ -10,7 +10,7 @@
#include "base/json/json_reader.h"
#include "base/json/json_writer.h"
-#include "base/profiler/scoped_profile.h"
+#include "base/profiler/scoped_tracker.h"
#include "base/strings/string_split.h"
#include "base/strings/string_util.h"
#include "base/strings/stringprintf.h"
@@ -935,8 +935,8 @@ void GaiaAuthFetcher::OnGetCheckConnectionInfoFetched(
}
void GaiaAuthFetcher::OnURLFetchComplete(const net::URLFetcher* source) {
- // TODO(vadimt): Remove ScopedProfile below once crbug.com/422577 is fixed.
- tracked_objects::ScopedProfile tracking_profile(
+ // TODO(vadimt): Remove ScopedTracker below once crbug.com/422577 is fixed.
+ tracked_objects::ScopedTracker tracking_profile(
FROM_HERE_WITH_EXPLICIT_FUNCTION(
"422577 GaiaAuthFetcher::OnURLFetchComplete"));
diff --git a/google_apis/gaia/gaia_oauth_client.cc b/google_apis/gaia/gaia_oauth_client.cc
index 0660507..25f03ee 100644
--- a/google_apis/gaia/gaia_oauth_client.cc
+++ b/google_apis/gaia/gaia_oauth_client.cc
@@ -7,7 +7,7 @@
#include "base/json/json_reader.h"
#include "base/logging.h"
#include "base/memory/scoped_ptr.h"
-#include "base/profiler/scoped_profile.h"
+#include "base/profiler/scoped_tracker.h"
#include "base/strings/string_util.h"
#include "base/values.h"
#include "google_apis/gaia/gaia_urls.h"
@@ -227,8 +227,8 @@ void GaiaOAuthClient::Core::MakeGaiaRequest(
// URLFetcher::Delegate implementation.
void GaiaOAuthClient::Core::OnURLFetchComplete(
const net::URLFetcher* source) {
- // TODO(vadimt): Remove ScopedProfile below once crbug.com/422577 is fixed.
- tracked_objects::ScopedProfile tracking_profile(
+ // TODO(vadimt): Remove ScopedTracker below once crbug.com/422577 is fixed.
+ tracked_objects::ScopedTracker tracking_profile(
FROM_HERE_WITH_EXPLICIT_FUNCTION(
"422577 GaiaOAuthClient::Core::OnURLFetchComplete"));
diff --git a/google_apis/gaia/identity_provider.cc b/google_apis/gaia/identity_provider.cc
index 73abe2a..86edfb8 100644
--- a/google_apis/gaia/identity_provider.cc
+++ b/google_apis/gaia/identity_provider.cc
@@ -2,7 +2,7 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#include "base/profiler/scoped_profile.h"
+#include "base/profiler/scoped_tracker.h"
#include "google_apis/gaia/identity_provider.h"
IdentityProvider::Observer::~Observer() {}
@@ -40,8 +40,8 @@ void IdentityProvider::RemoveObserver(Observer* observer) {
}
void IdentityProvider::OnRefreshTokenAvailable(const std::string& account_id) {
- // TODO(vadimt): Remove ScopedProfile below once crbug.com/422460 is fixed.
- tracked_objects::ScopedProfile tracking_profile(
+ // TODO(vadimt): Remove ScopedTracker below once crbug.com/422460 is fixed.
+ tracked_objects::ScopedTracker tracking_profile(
FROM_HERE_WITH_EXPLICIT_FUNCTION(
"422460 IdentityProvider::OnRefreshTokenAvailable"));
diff --git a/google_apis/gaia/oauth2_access_token_fetcher_impl.cc b/google_apis/gaia/oauth2_access_token_fetcher_impl.cc
index 7ef13ab..0a4f09d 100644
--- a/google_apis/gaia/oauth2_access_token_fetcher_impl.cc
+++ b/google_apis/gaia/oauth2_access_token_fetcher_impl.cc
@@ -11,7 +11,7 @@
#include "base/json/json_reader.h"
#include "base/metrics/histogram.h"
#include "base/metrics/sparse_histogram.h"
-#include "base/profiler/scoped_profile.h"
+#include "base/profiler/scoped_tracker.h"
#include "base/strings/string_util.h"
#include "base/strings/stringprintf.h"
#include "base/time/time.h"
@@ -259,8 +259,8 @@ void OAuth2AccessTokenFetcherImpl::OnGetTokenFailure(
void OAuth2AccessTokenFetcherImpl::OnURLFetchComplete(
const net::URLFetcher* source) {
- // TODO(vadimt): Remove ScopedProfile below once crbug.com/422577 is fixed.
- tracked_objects::ScopedProfile tracking_profile(
+ // TODO(vadimt): Remove ScopedTracker below once crbug.com/422577 is fixed.
+ tracked_objects::ScopedTracker tracking_profile(
FROM_HERE_WITH_EXPLICIT_FUNCTION(
"422577 OAuth2AccessTokenFetcherImpl::OnURLFetchComplete"));
diff --git a/google_apis/gaia/oauth2_api_call_flow.cc b/google_apis/gaia/oauth2_api_call_flow.cc
index 9038328..ade25d7 100644
--- a/google_apis/gaia/oauth2_api_call_flow.cc
+++ b/google_apis/gaia/oauth2_api_call_flow.cc
@@ -8,7 +8,7 @@
#include <vector>
#include "base/basictypes.h"
-#include "base/profiler/scoped_profile.h"
+#include "base/profiler/scoped_tracker.h"
#include "base/strings/stringprintf.h"
#include "google_apis/gaia/gaia_urls.h"
#include "net/base/escape.h"
@@ -67,8 +67,8 @@ std::string OAuth2ApiCallFlow::CreateApiCallBodyContentType() {
}
void OAuth2ApiCallFlow::OnURLFetchComplete(const net::URLFetcher* source) {
- // TODO(vadimt): Remove ScopedProfile below once crbug.com/422577 is fixed.
- tracked_objects::ScopedProfile tracking_profile(
+ // TODO(vadimt): Remove ScopedTracker below once crbug.com/422577 is fixed.
+ tracked_objects::ScopedTracker tracking_profile(
FROM_HERE_WITH_EXPLICIT_FUNCTION(
"422577 OAuth2ApiCallFlow::OnURLFetchComplete"));
diff --git a/google_apis/gaia/oauth2_token_service.cc b/google_apis/gaia/oauth2_token_service.cc
index 0945723..dac940b 100644
--- a/google_apis/gaia/oauth2_token_service.cc
+++ b/google_apis/gaia/oauth2_token_service.cc
@@ -9,7 +9,7 @@
#include "base/bind.h"
#include "base/memory/weak_ptr.h"
#include "base/message_loop/message_loop.h"
-#include "base/profiler/scoped_profile.h"
+#include "base/profiler/scoped_tracker.h"
#include "base/rand_util.h"
#include "base/stl_util.h"
#include "base/time/time.h"
@@ -757,8 +757,8 @@ void OAuth2TokenService::CancelFetchers(
void OAuth2TokenService::FireRefreshTokenAvailable(
const std::string& account_id) {
- // TODO(vadimt): Remove ScopedProfile below once crbug.com/422460 is fixed.
- tracked_objects::ScopedProfile tracking_profile(
+ // TODO(vadimt): Remove ScopedTracker below once crbug.com/422460 is fixed.
+ tracked_objects::ScopedTracker tracking_profile(
FROM_HERE_WITH_EXPLICIT_FUNCTION(
"422460 OAuth2TokenService::FireRefreshTokenAvailable"));
@@ -773,8 +773,8 @@ void OAuth2TokenService::FireRefreshTokenRevoked(
}
void OAuth2TokenService::FireRefreshTokensLoaded() {
- // TODO(vadimt): Remove ScopedProfile below once crbug.com/422460 is fixed.
- tracked_objects::ScopedProfile tracking_profile(
+ // TODO(vadimt): Remove ScopedTracker below once crbug.com/422460 is fixed.
+ tracked_objects::ScopedTracker tracking_profile(
FROM_HERE_WITH_EXPLICIT_FUNCTION(
"422460 OAuth2TokenService::FireRefreshTokensLoaded"));
diff --git a/google_apis/gcm/base/socket_stream.cc b/google_apis/gcm/base/socket_stream.cc
index 52224e3..ffea696 100644
--- a/google_apis/gcm/base/socket_stream.cc
+++ b/google_apis/gcm/base/socket_stream.cc
@@ -6,7 +6,7 @@
#include "base/bind.h"
#include "base/callback.h"
-#include "base/profiler/scoped_profile.h"
+#include "base/profiler/scoped_tracker.h"
#include "net/base/io_buffer.h"
#include "net/socket/stream_socket.h"
@@ -163,8 +163,8 @@ SocketInputStream::State SocketInputStream::GetState() const {
void SocketInputStream::RefreshCompletionCallback(
const base::Closure& callback, int result) {
- // TODO(vadimt): Remove ScopedProfile below once crbug.com/418183 is fixed.
- tracked_objects::ScopedProfile tracking_profile(
+ // TODO(vadimt): Remove ScopedTracker below once crbug.com/418183 is fixed.
+ tracked_objects::ScopedTracker tracking_profile(
FROM_HERE_WITH_EXPLICIT_FUNCTION(
"418183 DoReadCallback => SocketInputStream::RefreshCompletionC..."));